Parentage package — snptools version 1.0.8 documentation

# Parentage package

Search for paternity according to ICAR recommendations https://www.icar.org/Documents/GenoEx/ICAR%20Guidelines%20for%20Parentage%20Verification%20and%20Parentage%20Discovery%20based%20on%20SNP.pdf

https://www.icar.org/Documents/GenoEx/ICAR%20Guidelines%20for%20Parentage%20Verification%20and%20Parentage%20Discovery%20based%20on%20SNP.pdf

class snplib.parentage.Discovery(isag_markers: Series | list | set | None = None)

  Bases: `object`

  Search for paternity according to ICAR recommendations

  Parameters:

    isag_markers – Fixed sample of markers to confirm paternity.

  __status_define() → None
  property num_conflicts: None | int
  property perc_conflicts: None | float
  search_parent(data: DataFrame, descendant: str, parents: str, snp_name_col: str) → None

    Search for paternity.

    Parameters:

      - data – SNP data for descendant and parent.

      - descendant – Columns name of the descendant in the data.

      - parents – Columns name or list name of the parents in the data.

      - snp_name_col – SNP columns name is data.

  property status: None | str

    The status of each parent discovered.

class snplib.parentage.Verification(isag_marks: Series | list | set | None = None)

  Bases: `object`

  Verification of paternity according to ICAR recommendations.

  Parameters:

    isag_marks – Fixed sample of markers to confirm paternity.

  check_on(data: DataFrame, descendant: str, parent: str, snp_name_col: str) → None

    Verification of paternity according to ICAR recommendations.

    Parameters:

      - data – SNP data for descendant and parent.

      - descendant – Columns name of the descendant in the data.

      - parent – Columns name of the parent in the data.

      - snp_name_col – SNP column name in data.

  property num_conflicts: None | int
  property status: None | str

snplib.parentage.isag_disc() → DataFrame

snplib.parentage.isag_verif() → DataFrame